@@ -29,6 +29,7 @@ History::History( QObject* parent )
     : QObject( parent ),
       m_top(0L),
       m_popup( new KlipperPopup( this ) ),
+      m_maxSize(0),
       m_topIsUserSelected( false ),
       m_nextCycle(0L)
 {
@@ -45,7 +46,6 @@ void History::insert( HistoryItem* item ) {
     if ( !item )
         return;
 
-    m_topIsUserSelected = false;
     const HistoryItem* existingItem = this->find(item->uuid());
     if ( existingItem ) {
         if ( existingItem == m_top) {
@@ -55,6 +55,7 @@ void History::insert( HistoryItem* item ) {
     } else {
         forceInsert( item );
     }
+    m_topIsUserSelected = false;
 
     emit topChanged();
 
@@ -91,6 +92,10 @@ void History::trim() {
     if (m_items.size()<=1) {
         m_nextCycle = 0L;
     }
+    if (m_items.isEmpty()) {
+        // force top to nullptr
+        m_top = nullptr;
+    }
     emit changed();
 }
 
@@ -105,6 +110,11 @@ void History::remove( const HistoryItem* newItem ) {
 
     if (*it == m_top) {
         m_top = m_items[m_top->next_uuid()];
+        if (m_top == *it) {
+            // last element in chain
+            m_top = nullptr;
+        }
+        m_topIsUserSelected = false;
     }
     m_items[(*it)->previous_uuid()]->chain(m_items[(*it)->next_uuid()]);
     m_items.erase(it);
@@ -116,6 +126,7 @@ void History::slotClear() {
     qDeleteAll(m_items);
     m_items.clear();
     m_top = 0L;
+    m_topIsUserSelected = false;
     emit changed();
 }
 
